"""Constants and other variables used across the package."""

from typing import Iterable


DEFAULT_NAMES: Iterable[str] = ("Terry Pratchett",)
